ultradns
    * ``auth_token`` Specify token for authentication; if not set --auth-token, --auth-password are used

    * ``auth_username`` Specify username for authentication

    * ``auth_password`` Specify password for authentication
